# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neuroshard.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'neuroshard.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10neuroshard.proto\x12\nneuroshard\"\x96\x01\n\x10InferenceRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x13\n\x0btensor_data\x18\x03 \x01(\x0c\x12\x14\n\x0c\x64raft_tokens\x18\x04 \x03(\x05\x12\x19\n\x11sender_reputation\x18\x05 \x01(\x02\x12\x14\n\x0csource_layer\x18\x06 \x01(\x05\"\xa5\x01\n\x11InferenceResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x13\n\x0btensor_data\x18\x04 \x01(\x0c\x12\x16\n\x0eis_speculative\x18\x05 \x01(\x08\x12\x13\n\x0bvalid_count\x18\x06 \x01(\x05\x12\x12\n\nnext_token\x18\x07 \x01(\x05\"$\n\rWeightRequest\x12\x13\n\x0bshard_range\x18\x01 \x01(\t\"&\n\x0eWeightResponse\x12\x14\n\x0cweights_data\x18\x01 \x01(\x0c\"\xd6\x02\n\x12GossipProofRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x0e\n\x06uptime\x18\x03 \x01(\x01\x12\x11\n\tsignature\x18\x04 \x01(\t\x12\x13\n\x0btoken_count\x18\x05 \x01(\x03\x12\x18\n\x10training_batches\x18\x06 \x01(\x05\x12\x13\n\x0blayers_held\x18\x07 \x01(\x05\x12\x15\n\rhas_embedding\x18\x08 \x01(\x08\x12\x13\n\x0bhas_lm_head\x18\t \x01(\x08\x12\x12\n\nproof_type\x18\n \x01(\t\x12\r\n\x05nonce\x18\x0b \x01(\t\x12\x12\n\npublic_key\x18\x0c \x01(\t\x12\x14\n\x0c\x64\x61ta_samples\x18\r \x01(\x05\x12\x12\n\nmodel_hash\x18\x0e \x01(\t\x12\x12\n\nrequest_id\x18\x0f \x01(\t\x12\x14\n\x0c\x63urrent_loss\x18\x10 \x01(\x01\"\'\n\x13GossipProofResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\"\x8a\x01\n\x18GossipTransactionRequest\x12\x11\n\tsender_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x11\n\tsignature\x18\x05 \x01(\t\x12\x0f\n\x07tx_hash\x18\x06 \x01(\t\"=\n\x19GossipTransactionResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x85\x01\n\x12GossipStakeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x14\n\x0clocked_until\x18\x03 \x01(\x01\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x11\n\tsignature\x18\x05 \x01(\t\x12\x12\n\npublic_key\x18\x06 \x01(\t\"7\n\x13GossipStakeResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x8a\x02\n\x16ProofValidationRequest\x12\x17\n\x0fproof_signature\x18\x01 \x01(\t\x12\x14\n\x0csubmitter_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x01\x12\x16\n\x0euptime_seconds\x18\x04 \x01(\x01\x12\x18\n\x10tokens_processed\x18\x05 \x01(\x03\x12\x18\n\x10training_batches\x18\x06 \x01(\x05\x12\x13\n\x0blayers_held\x18\x07 \x01(\x05\x12\x15\n\rhas_embedding\x18\x08 \x01(\x08\x12\x13\n\x0bhas_lm_head\x18\t \x01(\x08\x12\x12\n\nproof_type\x18\n \x01(\t\x12\r\n\x05nonce\x18\x0b \x01(\t\"j\n\x17ProofValidationResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x14\n\x0cvalidator_id\x18\x03 \x01(\t\x12\x17\n\x0fvalidator_stake\x18\x04 \x01(\x01\"\xa4\x01\n\x15ValidationVoteRequest\x12\x17\n\x0fproof_signature\x18\x01 \x01(\t\x12\x14\n\x0cvalidator_id\x18\x02 \x01(\t\x12\x17\n\x0fvalidator_stake\x18\x03 \x01(\x01\x12\x0c\n\x04vote\x18\x04 \x01(\x08\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x01\x12\x11\n\tsignature\x18\x07 \x01(\t\"\xa7\x01\n\x16ValidationVoteResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x19\n\x11total_valid_stake\x18\x03 \x01(\x01\x12\x1b\n\x13total_invalid_stake\x18\x04 \x01(\x01\x12\x19\n\x11\x63onsensus_reached\x18\x05 \x01(\x08\x12\x18\n\x10\x63onsensus_result\x18\x06 \x01(\x08\"\xaa\x02\n\x15GossipGradientRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x10\n\x08round_id\x18\x02 \x01(\x05\x12\x12\n\nmodel_hash\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x12\n\nbatch_size\x18\x05 \x01(\x05\x12\x0c\n\x04loss\x18\x06 \x01(\x01\x12N\n\x0flayer_gradients\x18\x07 \x03(\x0b\x32\x35.neuroshard.GossipGradientRequest.LayerGradientsEntry\x12\x11\n\tsignature\x18\x08 \x01(\t\x12\x0b\n\x03ttl\x18\t \x01(\x05\x1a\x35\n\x13LayerGradientsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"Q\n\x16GossipGradientResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x15\n\rcurrent_round\x18\x03 \x01(\x05\"?\n\x14GetCheckpointRequest\x12\x12\n\nmodel_hash\x18\x01 \x01(\t\x12\x13\n\x0bmin_version\x18\x02 \x01(\x05\"\xa0\x01\n\x15GetCheckpointResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x12\n\nmodel_hash\x18\x04 \x01(\t\x12\r\n\x05phase\x18\x05 \x01(\t\x12\x17\n\x0f\x63heckpoint_data\x18\x06 \x01(\x0c\x12\x12\n\ntotal_size\x18\x07 \x01(\x03\"\x1a\n\x18GetCheckpointInfoRequest\"m\n\x19GetCheckpointInfoResponse\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x12\n\nmodel_hash\x18\x02 \x01(\t\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x0e\n\x06params\x18\x04 \x01(\x03\x12\x0c\n\x04loss\x18\x05 \x01(\x01\"\xa0\x02\n\x16PipelineForwardRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x15\n\rhidden_states\x18\x03 \x01(\x0c\x12\x14\n\x0chidden_shape\x18\x04 \x03(\x03\x12\x16\n\x0e\x61ttention_mask\x18\x05 \x01(\x0c\x12\x14\n\x0cposition_ids\x18\x06 \x01(\x0c\x12\x17\n\x0fpast_key_values\x18\x07 \x03(\x0c\x12\x11\n\tuse_cache\x18\x08 \x01(\x08\x12\x14\n\x0csource_shard\x18\t \x01(\x05\x12\x14\n\x0ctarget_shard\x18\n \x01(\x05\x12\x17\n\x0ftraining_labels\x18\x0b \x01(\x0c\x12\x12\n\nsender_url\x18\x0c \x01(\t\"\xe1\x01\n\x17PipelineForwardResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x15\n\rhidden_states\x18\x04 \x01(\x0c\x12\x14\n\x0chidden_shape\x18\x05 \x03(\x03\x12\x17\n\x0fpast_key_values\x18\x06 \x03(\x0c\x12\x10\n\x08is_final\x18\x07 \x01(\x08\x12\x0e\n\x06logits\x18\x08 \x01(\x0c\x12\x14\n\x0clogits_shape\x18\t \x03(\x03\x12\x0c\n\x04loss\x18\n \x01(\x01\"\x80\x01\n\x17PipelineBackwardRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x13\n\x0bgrad_output\x18\x03 \x01(\x0c\x12\x12\n\ngrad_shape\x18\x04 \x03(\x03\x12\x14\n\x0ctarget_shard\x18\x05 \x01(\x05\"B\n\x18PipelineBackwardResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"\x15\n\x13GetShardInfoRequest\"\xea\x01\n\x14GetShardInfoResponse\x12\x10\n\x08shard_id\x18\x01 \x01(\x05\x12\x14\n\x0ctotal_shards\x18\x02 \x01(\x05\x12\x13\n\x0bstart_layer\x18\x03 \x01(\x05\x12\x11\n\tend_layer\x18\x04 \x01(\x05\x12\x15\n\rhas_embedding\x18\x05 \x01(\x08\x12\x13\n\x0bhas_lm_head\x18\x06 \x01(\x08\x12\x0f\n\x07version\x18\x07 \x01(\x05\x12\x12\n\nmodel_hash\x18\x08 \x01(\t\x12\x1b\n\x13\x61vailable_memory_mb\x18\t \x01(\x02\x12\x14\n\x0c\x63urrent_load\x18\n \x01(\x02\"S\n\x14GetShardChunkRequest\x12\x10\n\x08shard_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63hunk_index\x18\x02 \x01(\x05\x12\x14\n\x0crequester_id\x18\x03 \x01(\t\"w\n\x15GetShardChunkResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x12\n\ntotal_size\x18\x04 \x01(\x03\x12\x14\n\x0ctotal_chunks\x18\x05 \x01(\x05\"8\n\x0b\x44HTNodeInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\x0c\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"9\n\x0e\x44HTPingRequest\x12\'\n\x06sender\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\"=\n\x0f\x44HTPingResponse\x12*\n\tresponder\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\"V\n\x0f\x44HTStoreRequest\x12\'\n\x06sender\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\r\n\x05value\x18\x03 \x01(\t\"O\n\x10\x44HTStoreResponse\x12*\n\tresponder\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\x0f\n\x07success\x18\x02 \x01(\x08\"P\n\x12\x44HTFindNodeRequest\x12\'\n\x06sender\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\x11\n\ttarget_id\x18\x02 \x01(\x0c\"i\n\x13\x44HTFindNodeResponse\x12*\n\tresponder\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12&\n\x05nodes\x18\x02 \x03(\x0b\x32\x17.neuroshard.DHTNodeInfo\"K\n\x13\x44HTFindValueRequest\x12\'\n\x06sender\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\x0b\n\x03key\x18\x02 \x01(\x0c\"\x88\x01\n\x14\x44HTFindValueResponse\x12*\n\tresponder\x18\x01 \x01(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12&\n\x05nodes\x18\x03 \x03(\x0b\x32\x17.neuroshard.DHTNodeInfo\x12\r\n\x05\x66ound\x18\x04 \x01(\x08\"\xdc\x01\n\x15TensorExchangeRequest\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x10\n\x08layer_id\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\x05\x12\x11\n\tchunk_idx\x18\x04 \x01(\x05\x12\x17\n\x0fsender_shard_id\x18\x05 \x01(\x05\x12\x14\n\x0ctotal_shards\x18\x06 \x01(\x05\x12\x13\n\x0btensor_data\x18\x07 \x01(\x0c\x12\x14\n\x0ctensor_shape\x18\x08 \x03(\x03\x12\r\n\x05\x64type\x18\t \x01(\t\x12\x11\n\treduce_op\x18\n \x01(\t\"\x81\x01\n\x16TensorExchangeResponse\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x13\n\x0btensor_data\x18\x04 \x01(\x0c\x12\x14\n\x0ctensor_shape\x18\x05 \x03(\x03\"\xd0\x01\n\x14PartialResultRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x10\n\x08layer_id\x18\x03 \x01(\x05\x12\x17\n\x0fsender_shard_id\x18\x04 \x01(\x05\x12\x14\n\x0ctotal_shards\x18\x05 \x01(\x05\x12\x16\n\x0epartial_tensor\x18\x06 \x01(\x0c\x12\x14\n\x0ctensor_shape\x18\x07 \x03(\x03\x12\r\n\x05\x64type\x18\x08 \x01(\t\x12\x10\n\x08is_final\x18\t \x01(\x08\"\x85\x01\n\x15PartialResultResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x14\n\x0c\x61ll_received\x18\x03 \x01(\x08\x12\x17\n\x0f\x63ombined_tensor\x18\x04 \x01(\x0c\x12\x14\n\x0ctensor_shape\x18\x05 \x03(\x03\"\xb9\x02\n\tModelInfo\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x12\n\nnum_layers\x18\x05 \x01(\x05\x12\x12\n\nhidden_dim\x18\x06 \x01(\x05\x12\x11\n\tnum_heads\x18\x07 \x01(\x05\x12\x12\n\nvocab_size\x18\x08 \x01(\x05\x12\x15\n\rtotal_size_mb\x18\t \x01(\x02\x12\x15\n\rlayer_size_mb\x18\n \x01(\x02\x12 \n\x18supports_tensor_parallel\x18\x0b \x01(\x08\x12\"\n\x1asupports_pipeline_parallel\x18\x0c \x01(\x08\x12\x16\n\x0erequired_stake\x18\r \x01(\x02\x12\x10\n\x08\x61pproved\x18\x0e \x01(\x08\"A\n\x11ListModelsRequest\x12\x15\n\rapproved_only\x18\x01 \x01(\x08\x12\x15\n\rfamily_filter\x18\x02 \x01(\t\";\n\x12ListModelsResponse\x12%\n\x06models\x18\x01 \x03(\x0b\x32\x15.neuroshard.ModelInfo\"\x9f\x02\n\x12ModelNetworkStatus\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x13\n\x0btotal_nodes\x18\x02 \x01(\x05\x12\x18\n\x10is_fully_covered\x18\x03 \x01(\x08\x12\x1a\n\x12is_inference_ready\x18\x04 \x01(\x08\x12\x16\n\x0e\x61vg_latency_ms\x18\x05 \x01(\x02\x12\x13\n\x0btotal_stake\x18\x06 \x01(\x02\x12I\n\x0elayer_coverage\x18\x07 \x03(\x0b\x32\x31.neuroshard.ModelNetworkStatus.LayerCoverageEntry\x1a\x34\n\x12LayerCoverageEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\")\n\x15GetModelStatusRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"H\n\x16GetModelStatusResponse\x12.\n\x06status\x18\x01 \x01(\x0b\x32\x1e.neuroshard.ModelNetworkStatus\"\xbd\x01\n\x17TensorShardAnnouncement\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08layer_id\x18\x02 \x01(\x05\x12\x10\n\x08shard_id\x18\x03 \x01(\x05\x12\x14\n\x0ctotal_shards\x18\x04 \x01(\x05\x12\x10\n\x08node_url\x18\x05 \x01(\t\x12\x11\n\tgrpc_addr\x18\x06 \x01(\t\x12\x1b\n\x13\x61vailable_memory_mb\x18\x07 \x01(\x02\x12\x14\n\x0c\x63urrent_load\x18\x08 \x01(\x02\"J\n\x14\x41nnounceShardRequest\x12\x32\n\x05shard\x18\x01 \x01(\x0b\x32#.neuroshard.TensorShardAnnouncement\"@\n\x15\x41nnounceShardResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"k\n\x15\x46indShardPeersRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08layer_id\x18\x02 \x01(\x05\x12\x14\n\x0ctotal_shards\x18\x03 \x01(\x05\x12\x18\n\x10\x65xclude_shard_id\x18\x04 \x01(\x05\"L\n\x16\x46indShardPeersResponse\x12\x32\n\x05peers\x18\x01 \x03(\x0b\x32#.neuroshard.TensorShardAnnouncement\"\x93\x02\n\x13SwarmForwardRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x15\n\rhidden_states\x18\x03 \x01(\x0c\x12\x14\n\x0chidden_shape\x18\x04 \x03(\x03\x12\x14\n\x0ctarget_layer\x18\x05 \x01(\x05\x12\x12\n\nsender_url\x18\x06 \x01(\t\x12\x10\n\x08priority\x18\x07 \x01(\x05\x12\x16\n\x0emicro_batch_id\x18\x08 \x01(\x05\x12\x13\n\x0bis_backward\x18\t \x01(\x08\x12\x15\n\rrequires_grad\x18\n \x01(\x08\x12\x13\n\x0bgrad_output\x18\x0b \x01(\x0c\x12\x12\n\ngrad_shape\x18\x0c \x03(\x03\"h\n\x14SwarmForwardResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x14\n\x0c\x62uffer_depth\x18\x04 \x01(\x05\"\x14\n\x12SwarmStatusRequest\"\xf2\x02\n\x13SwarmStatusResponse\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x13\n\x0blayer_start\x18\x02 \x01(\x05\x12\x11\n\tlayer_end\x18\x03 \x01(\x05\x12\x19\n\x11inbound_fill_rate\x18\x04 \x01(\x02\x12\x1a\n\x12outbound_fill_rate\x18\x05 \x01(\x02\x12\x1b\n\x13inbound_queue_depth\x18\x06 \x01(\x05\x12\x1c\n\x14outbound_queue_depth\x18\x07 \x01(\x05\x12\x1b\n\x13\x61vailable_memory_mb\x18\x08 \x01(\x05\x12\x17\n\x0fgpu_utilization\x18\t \x01(\x02\x12\x13\n\x0bis_training\x18\n \x01(\x08\x12 \n\x18is_accepting_activations\x18\x0b \x01(\x08\x12\x13\n\x0btotal_steps\x18\x0c \x01(\x03\x12\x17\n\x0flocal_only_rate\x18\r \x01(\x02\x12\x15\n\rerror_message\x18\x0e \x01(\t\"\xb2\x01\n\x19UpdatePeerCapacityRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x11\n\tgrpc_addr\x18\x02 \x01(\t\x12\x13\n\x0blayer_start\x18\x03 \x01(\x05\x12\x11\n\tlayer_end\x18\x04 \x01(\x05\x12\x13\n\x0bqueue_depth\x18\x05 \x01(\x05\x12\x1b\n\x13\x61vailable_memory_mb\x18\x06 \x01(\x05\x12\x17\n\x0fgpu_utilization\x18\x07 \x01(\x02\"D\n\x1aUpdatePeerCapacityResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t2\x81\x13\n\x11NeuroShardService\x12R\n\x0fStreamInference\x12\x1c.neuroshard.InferenceRequest\x1a\x1d.neuroshard.InferenceResponse(\x01\x30\x01\x12M\n\x0eUnaryInference\x12\x1c.neuroshard.InferenceRequest\x1a\x1d.neuroshard.InferenceResponse\x12\x43\n\nGetWeights\x12\x19.neuroshard.WeightRequest\x1a\x1a.neuroshard.WeightResponse\x12N\n\x0bGossipProof\x12\x1e.neuroshard.GossipProofRequest\x1a\x1f.neuroshard.GossipProofResponse\x12`\n\x11GossipTransaction\x12$.neuroshard.GossipTransactionRequest\x1a%.neuroshard.GossipTransactionResponse\x12N\n\x0bGossipStake\x12\x1e.neuroshard.GossipStakeRequest\x1a\x1f.neuroshard.GossipStakeResponse\x12\x61\n\x16RequestProofValidation\x12\".neuroshard.ProofValidationRequest\x1a#.neuroshard.ProofValidationResponse\x12]\n\x14GossipValidationVote\x12!.neuroshard.ValidationVoteRequest\x1a\".neuroshard.ValidationVoteResponse\x12W\n\x0eGossipGradient\x12!.neuroshard.GossipGradientRequest\x1a\".neuroshard.GossipGradientResponse\x12T\n\rGetCheckpoint\x12 .neuroshard.GetCheckpointRequest\x1a!.neuroshard.GetCheckpointResponse\x12`\n\x11GetCheckpointInfo\x12$.neuroshard.GetCheckpointInfoRequest\x1a%.neuroshard.GetCheckpointInfoResponse\x12Z\n\x0fPipelineForward\x12\".neuroshard.PipelineForwardRequest\x1a#.neuroshard.PipelineForwardResponse\x12]\n\x10PipelineBackward\x12#.neuroshard.PipelineBackwardRequest\x1a$.neuroshard.PipelineBackwardResponse\x12Q\n\x0cGetShardInfo\x12\x1f.neuroshard.GetShardInfoRequest\x1a .neuroshard.GetShardInfoResponse\x12T\n\rGetShardChunk\x12 .neuroshard.GetShardChunkRequest\x1a!.neuroshard.GetShardChunkResponse\x12\x42\n\x07\x44HTPing\x12\x1a.neuroshard.DHTPingRequest\x1a\x1b.neuroshard.DHTPingResponse\x12\x45\n\x08\x44HTStore\x12\x1b.neuroshard.DHTStoreRequest\x1a\x1c.neuroshard.DHTStoreResponse\x12N\n\x0b\x44HTFindNode\x12\x1e.neuroshard.DHTFindNodeRequest\x1a\x1f.neuroshard.DHTFindNodeResponse\x12Q\n\x0c\x44HTFindValue\x12\x1f.neuroshard.DHTFindValueRequest\x1a .neuroshard.DHTFindValueResponse\x12W\n\x0eTensorExchange\x12!.neuroshard.TensorExchangeRequest\x1a\".neuroshard.TensorExchangeResponse\x12X\n\x11SendPartialResult\x12 .neuroshard.PartialResultRequest\x1a!.neuroshard.PartialResultResponse\x12Z\n\x13\x41nnounceTensorShard\x12 .neuroshard.AnnounceShardRequest\x1a!.neuroshard.AnnounceShardResponse\x12]\n\x14\x46indTensorShardPeers\x12!.neuroshard.FindShardPeersRequest\x1a\".neuroshard.FindShardPeersResponse\x12K\n\nListModels\x12\x1d.neuroshard.ListModelsRequest\x1a\x1e.neuroshard.ListModelsResponse\x12W\n\x0eGetModelStatus\x12!.neuroshard.GetModelStatusRequest\x1a\".neuroshard.GetModelStatusResponse\x12Q\n\x0cSwarmForward\x12\x1f.neuroshard.SwarmForwardRequest\x1a .neuroshard.SwarmForwardResponse\x12Q\n\x0eGetSwarmStatus\x12\x1e.neuroshard.SwarmStatusRequest\x1a\x1f.neuroshard.SwarmStatusResponse\x12\x63\n\x12UpdatePeerCapacity\x12%.neuroshard.UpdatePeerCapacityRequest\x1a&.neuroshard.UpdatePeerCapacityResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neuroshard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GOSSIPGRADIENTREQUEST_LAYERGRADIENTSENTRY']._loaded_options = None
  _globals['_GOSSIPGRADIENTREQUEST_LAYERGRADIENTSENTRY']._serialized_options = b'8\001'
  _globals['_MODELNETWORKSTATUS_LAYERCOVERAGEENTRY']._loaded_options = None
  _globals['_MODELNETWORKSTATUS_LAYERCOVERAGEENTRY']._serialized_options = b'8\001'
  _globals['_INFERENCEREQUEST']._serialized_start=33
  _globals['_INFERENCEREQUEST']._serialized_end=183
  _globals['_INFERENCERESPONSE']._serialized_start=186
  _globals['_INFERENCERESPONSE']._serialized_end=351
  _globals['_WEIGHTREQUEST']._serialized_start=353
  _globals['_WEIGHTREQUEST']._serialized_end=389
  _globals['_WEIGHTRESPONSE']._serialized_start=391
  _globals['_WEIGHTRESPONSE']._serialized_end=429
  _globals['_GOSSIPPROOFREQUEST']._serialized_start=432
  _globals['_GOSSIPPROOFREQUEST']._serialized_end=774
  _globals['_GOSSIPPROOFRESPONSE']._serialized_start=776
  _globals['_GOSSIPPROOFRESPONSE']._serialized_end=815
  _globals['_GOSSIPTRANSACTIONREQUEST']._serialized_start=818
  _globals['_GOSSIPTRANSACTIONREQUEST']._serialized_end=956
  _globals['_GOSSIPTRANSACTIONRESPONSE']._serialized_start=958
  _globals['_GOSSIPTRANSACTIONRESPONSE']._serialized_end=1019
  _globals['_GOSSIPSTAKEREQUEST']._serialized_start=1022
  _globals['_GOSSIPSTAKEREQUEST']._serialized_end=1155
  _globals['_GOSSIPSTAKERESPONSE']._serialized_start=1157
  _globals['_GOSSIPSTAKERESPONSE']._serialized_end=1212
  _globals['_PROOFVALIDATIONREQUEST']._serialized_start=1215
  _globals['_PROOFVALIDATIONREQUEST']._serialized_end=1481
  _globals['_PROOFVALIDATIONRESPONSE']._serialized_start=1483
  _globals['_PROOFVALIDATIONRESPONSE']._serialized_end=1589
  _globals['_VALIDATIONVOTEREQUEST']._serialized_start=1592
  _globals['_VALIDATIONVOTEREQUEST']._serialized_end=1756
  _globals['_VALIDATIONVOTERESPONSE']._serialized_start=1759
  _globals['_VALIDATIONVOTERESPONSE']._serialized_end=1926
  _globals['_GOSSIPGRADIENTREQUEST']._serialized_start=1929
  _globals['_GOSSIPGRADIENTREQUEST']._serialized_end=2227
  _globals['_GOSSIPGRADIENTREQUEST_LAYERGRADIENTSENTRY']._serialized_start=2174
  _globals['_GOSSIPGRADIENTREQUEST_LAYERGRADIENTSENTRY']._serialized_end=2227
  _globals['_GOSSIPGRADIENTRESPONSE']._serialized_start=2229
  _globals['_GOSSIPGRADIENTRESPONSE']._serialized_end=2310
  _globals['_GETCHECKPOINTREQUEST']._serialized_start=2312
  _globals['_GETCHECKPOINTREQUEST']._serialized_end=2375
  _globals['_GETCHECKPOINTRESPONSE']._serialized_start=2378
  _globals['_GETCHECKPOINTRESPONSE']._serialized_end=2538
  _globals['_GETCHECKPOINTINFOREQUEST']._serialized_start=2540
  _globals['_GETCHECKPOINTINFOREQUEST']._serialized_end=2566
  _globals['_GETCHECKPOINTINFORESPONSE']._serialized_start=2568
  _globals['_GETCHECKPOINTINFORESPONSE']._serialized_end=2677
  _globals['_PIPELINEFORWARDREQUEST']._serialized_start=2680
  _globals['_PIPELINEFORWARDREQUEST']._serialized_end=2968
  _globals['_PIPELINEFORWARDRESPONSE']._serialized_start=2971
  _globals['_PIPELINEFORWARDRESPONSE']._serialized_end=3196
  _globals['_PIPELINEBACKWARDREQUEST']._serialized_start=3199
  _globals['_PIPELINEBACKWARDREQUEST']._serialized_end=3327
  _globals['_PIPELINEBACKWARDRESPONSE']._serialized_start=3329
  _globals['_PIPELINEBACKWARDRESPONSE']._serialized_end=3395
  _globals['_GETSHARDINFOREQUEST']._serialized_start=3397
  _globals['_GETSHARDINFOREQUEST']._serialized_end=3418
  _globals['_GETSHARDINFORESPONSE']._serialized_start=3421
  _globals['_GETSHARDINFORESPONSE']._serialized_end=3655
  _globals['_GETSHARDCHUNKREQUEST']._serialized_start=3657
  _globals['_GETSHARDCHUNKREQUEST']._serialized_end=3740
  _globals['_GETSHARDCHUNKRESPONSE']._serialized_start=3742
  _globals['_GETSHARDCHUNKRESPONSE']._serialized_end=3861
  _globals['_DHTNODEINFO']._serialized_start=3863
  _globals['_DHTNODEINFO']._serialized_end=3919
  _globals['_DHTPINGREQUEST']._serialized_start=3921
  _globals['_DHTPINGREQUEST']._serialized_end=3978
  _globals['_DHTPINGRESPONSE']._serialized_start=3980
  _globals['_DHTPINGRESPONSE']._serialized_end=4041
  _globals['_DHTSTOREREQUEST']._serialized_start=4043
  _globals['_DHTSTOREREQUEST']._serialized_end=4129
  _globals['_DHTSTORERESPONSE']._serialized_start=4131
  _globals['_DHTSTORERESPONSE']._serialized_end=4210
  _globals['_DHTFINDNODEREQUEST']._serialized_start=4212
  _globals['_DHTFINDNODEREQUEST']._serialized_end=4292
  _globals['_DHTFINDNODERESPONSE']._serialized_start=4294
  _globals['_DHTFINDNODERESPONSE']._serialized_end=4399
  _globals['_DHTFINDVALUEREQUEST']._serialized_start=4401
  _globals['_DHTFINDVALUEREQUEST']._serialized_end=4476
  _globals['_DHTFINDVALUERESPONSE']._serialized_start=4479
  _globals['_DHTFINDVALUERESPONSE']._serialized_end=4615
  _globals['_TENSOREXCHANGEREQUEST']._serialized_start=4618
  _globals['_TENSOREXCHANGEREQUEST']._serialized_end=4838
  _globals['_TENSOREXCHANGERESPONSE']._serialized_start=4841
  _globals['_TENSOREXCHANGERESPONSE']._serialized_end=4970
  _globals['_PARTIALRESULTREQUEST']._serialized_start=4973
  _globals['_PARTIALRESULTREQUEST']._serialized_end=5181
  _globals['_PARTIALRESULTRESPONSE']._serialized_start=5184
  _globals['_PARTIALRESULTRESPONSE']._serialized_end=5317
  _globals['_MODELINFO']._serialized_start=5320
  _globals['_MODELINFO']._serialized_end=5633
  _globals['_LISTMODELSREQUEST']._serialized_start=5635
  _globals['_LISTMODELSREQUEST']._serialized_end=5700
  _globals['_LISTMODELSRESPONSE']._serialized_start=5702
  _globals['_LISTMODELSRESPONSE']._serialized_end=5761
  _globals['_MODELNETWORKSTATUS']._serialized_start=5764
  _globals['_MODELNETWORKSTATUS']._serialized_end=6051
  _globals['_MODELNETWORKSTATUS_LAYERCOVERAGEENTRY']._serialized_start=5999
  _globals['_MODELNETWORKSTATUS_LAYERCOVERAGEENTRY']._serialized_end=6051
  _globals['_GETMODELSTATUSREQUEST']._serialized_start=6053
  _globals['_GETMODELSTATUSREQUEST']._serialized_end=6094
  _globals['_GETMODELSTATUSRESPONSE']._serialized_start=6096
  _globals['_GETMODELSTATUSRESPONSE']._serialized_end=6168
  _globals['_TENSORSHARDANNOUNCEMENT']._serialized_start=6171
  _globals['_TENSORSHARDANNOUNCEMENT']._serialized_end=6360
  _globals['_ANNOUNCESHARDREQUEST']._serialized_start=6362
  _globals['_ANNOUNCESHARDREQUEST']._serialized_end=6436
  _globals['_ANNOUNCESHARDRESPONSE']._serialized_start=6438
  _globals['_ANNOUNCESHARDRESPONSE']._serialized_end=6502
  _globals['_FINDSHARDPEERSREQUEST']._serialized_start=6504
  _globals['_FINDSHARDPEERSREQUEST']._serialized_end=6611
  _globals['_FINDSHARDPEERSRESPONSE']._serialized_start=6613
  _globals['_FINDSHARDPEERSRESPONSE']._serialized_end=6689
  _globals['_SWARMFORWARDREQUEST']._serialized_start=6692
  _globals['_SWARMFORWARDREQUEST']._serialized_end=6967
  _globals['_SWARMFORWARDRESPONSE']._serialized_start=6969
  _globals['_SWARMFORWARDRESPONSE']._serialized_end=7073
  _globals['_SWARMSTATUSREQUEST']._serialized_start=7075
  _globals['_SWARMSTATUSREQUEST']._serialized_end=7095
  _globals['_SWARMSTATUSRESPONSE']._serialized_start=7098
  _globals['_SWARMSTATUSRESPONSE']._serialized_end=7468
  _globals['_UPDATEPEERCAPACITYREQUEST']._serialized_start=7471
  _globals['_UPDATEPEERCAPACITYREQUEST']._serialized_end=7649
  _globals['_UPDATEPEERCAPACITYRESPONSE']._serialized_start=7651
  _globals['_UPDATEPEERCAPACITYRESPONSE']._serialized_end=7719
  _globals['_NEUROSHARDSERVICE']._serialized_start=7722
  _globals['_NEUROSHARDSERVICE']._serialized_end=10155
# @@protoc_insertion_point(module_scope)
